@@ -2,7 +2,7 @@
 '''
 Class storing a bibliography
 
-A Class that to store a list of references (list of papers, books, manuals, ...)
+A Class that store a list of references (list of papers, books, manuals, ...)
 It is based in dictionaries, with a unique self-generated key
 
 Example of use:
@@ -25,8 +25,7 @@ print(unicode(it)) # Use this if it has non-ascii characters
 '''
 import sys
 import os
-
-# import textwrap
+from pathlib import Path
 import pickle as pickle
 
 # import bibitem
@@ -35,15 +34,15 @@ import pickle as pickle
 from . import bibitem
 from . import helper
 from . import latex
+from . import bibdb
 latex.register()
 
 
-# Index used for internally for each part of a name
-# (A_VON, A_LAST, A_JR, A_FIRST)= range(4)
-
+# Index used internally for each part of a name
+# (A_VON, A_LAST, A_FIRST, A_JR)= range(4)
 
 class BibList(dict):
-  '''Class storing a bibliography  (list of papers, books, manuals, ...)'''
+  """Class storing a bibliography(list of papers, books, manuals, ...)"""
 
   def __init__(self):
     self.ListItems = []
@@ -56,7 +55,17 @@ class BibList(dict):
     self.encoding = 'utf-8'
     self.bib = {}
 
+  def __len__(self):
+    return len(self.ListItems)
+
   def update(self, blist):
+    """
+    Update the bibiography list with a new bibliography list
+
+    Parameters
+    ----------
+    blist : BibList or dict Object
+    """
     try:
       self.bib.update(blist.bib)  # blist es un objeto del tipo BibList
       self.set_properties_from(blist)
@@ -67,18 +76,27 @@ class BibList(dict):
         raise TypeError('Argument incorrect type, must be BibList object')
 
   def set_properties_from(self, blist):
+    """Copy properties from other biblist object
+
+    Does not fail if properties are not found
+
+    Parameters
+    ----------
+    blist : BibList object
     """
-    Try to get properties from other biblist object
-    """
+    # JF: TODO: If blist is a dictionary we could make the list from the keys()
     try:
       self.ListItems += blist.ListItems
-      self.ListItems = list(set(self.ListItems))
     except BaseException:
       pass
+    else:
+      self.ListItems = list(set(self.ListItems))
+
     try:
       self.abbrevDict.update(blist.abbrevDict)
     except BaseException:
       pass
+
     if self.issorted:
       self.sort()
     else:
@@ -95,17 +113,26 @@ class BibList(dict):
 
   def __repr__(self):
     s = f"bib= {str(self.bib)}\n"
-    s += 'abbrevDict= %s\n' % (self.abbrevDict)
-    s += 'ListItems= %s\n' % (self.ListItems)
-    s += 'sortedList= %s\n' % (self.sortedList)
-    s += 'issorted= %s\n' % (self.issorted)
-    s += 'encoding= %s\n' % (self.encoding)
+    s += f'abbrevDict= {self.abbrevDict}\n'
+    s += f'ListItems= {self.ListItems}\n'
+    s += f'sortedList= {self.sortedList}\n'
+    s += f'issorted= {self.issorted}\n'
+    s += f'encoding= {self.encoding}\n'
     return s
 
   def preview(self, n=None):
-    """
-    Show a preview of the publications (sorted).
+    """Show a preview of the publications (sorted).
+
     Optionally, only show the first n of them. If n is None, show all publications.
+
+    Parameters
+    ----------
+    n : int
+      If not None, only the first n values are shown (Default value = None)
+
+    Returns
+    -------
+
     """
     s = ''
     nn = len(self.ListItems)
@@ -113,13 +140,27 @@ class BibList(dict):
       nn = min(n, nn)
     if not self.issorted:
       self.sort()
-    for l in self.sortedList[:nn]:
-      s += '{}\n'.format(self.get_item(l).preview())
+    for li in self.sortedList[:nn]:
+      s += '{}\n'.format(self.get_item(li).preview())
 
     # s = str(s, self.encoding, 'ignore')
     return s
 
   def add_item(self, bib, key=None):
+    """Add a new bibliography entry into the list
+
+    Parameters
+    ----------
+    bib : BibItem object or dict
+
+    key : string
+      key  (Default value = None)
+
+    Returns
+    -------
+    string:
+      Internal key of added item or None on failing
+    """
     be = bibitem.BibItem(bib, key)
     key = be.get_key()
     if key is None:
@@ -129,35 +170,63 @@ class BibList(dict):
 
     if key in self.ListItems:
       if key == self.get_item(key).get_field('_code'):
-        sys.stderr.write(
-            'W: ENTRY ALREADY PRESENT: %s (%s)\n' %
-            (key, bib['_code']))
-        return False
-      else:
-        key = be.get_field('_code')
+        sys.stderr.write(f"W: ENTRY ALREADY PRESENT: {key} {bib['_code']}\n")
+        return None
 
     self.bib[key] = be
     self.ListItems.append(key)
     self.sortedList.append(key)
     self.issorted = False
-    return True
+    return key
 
   def remove_item(self, key):
+    """Remove an entry from the List
+
+    Parameters
+    ----------
+    key : string
+      The item to remove
+    """
     if key in self.ListItems[:]:
       self.ListItems.remove(key)
       self.sortedList.remove(key)
-      del(self.bib[key])
+      del (self.bib[key])
       return True
     else:
       return False
 
   def get_items(self):
+    """List all items"""
     return list(self.bib.values())
 
   def get_item(self, key):
+    """Retrieve one entry
+
+    Parameters
+    ----------
+    key : string
+      key of the entry to retrieve
+
+    Returns
+    -------
+    BibItem object:
+      Bibliography entry
+    """
     return self.bib.get(key)
 
   def set_item(self, key, value):
+    """Sets one bibliography entry that already is in the list
+
+    If key is not in the list, does not add it.
+
+    Parameters
+    ----------
+    key : string
+      key to use
+
+    value : BibItem or dict
+      Value to update
+    """
     "Set the value of a given item (that already exists)"
     if key in self.ListItems:
       self.bib[key].update(value)
@@ -166,6 +235,20 @@ class BibList(dict):
       return False
 
   def insertAbbrev(self, abbrev, value):
+    """
+    Add an item to the list of abbreviations
+    Parameters
+    ----------
+    abbrev : string
+      name of the string
+
+    value : string
+      definition of the string
+
+    Returns
+    -------
+    True or False indicating if abbrev was added
+    """
     if abbrev in self.abbrevDict:
       return False
     self.abbrevDict[abbrev] = value
@@ -178,20 +261,27 @@ class BibList(dict):
       self.get_item(k).resolve_abbrevs(self.abbrevDict)
 
   def List(self):
+    """List all items in bibliography """
     return self.ListItems
 
-  def sort(self, order=[], reverse=None):
+  def sort(self, order=[], reverse=False):
+    """Sort the entries according to the specified order
+
+    Parameters
+    ----------
+    order : list
+      Each value is a string indicating a field (Default value = [])
+    reverse : bool
+      If sorting must be in reverse order  (Default value = False)
     """
-    Sort the entries according to the specified order
-    """
-    if order == []:
+    if not order:
       order = self.sortorder
     else:
       self.sortorder = order
-    if reverse is None:
-      reverse = self.reverse
-    else:
+    if reverse:
       self.reverse = reverse
+    else:
+      reverse = self.reverse
 
     numericfields = ['year', 'volume', 'number', 'firstpage', 'lastpage']
     sortorder = order
@@ -217,12 +307,28 @@ class BibList(dict):
     self.sortedList = [x[-1] for x in s]
     return self.sortedList
 
-  def search(self, findstr, fields=[], caseSens=False, types='all'):
-    """
-    Search on the bibliography for findstr
+  def search(self, findstr, fields=[], ignore_case=True, types='all'):
+    """Search on the bibliography
     The result is a list with the keys of the items that match the search
     keys are the keys that we look
     types are on what kind of publication do we search (article, book,...)
+
+    Parameters
+    ----------
+    findstr : string
+      Expression to search for
+
+    fields : list-like
+      fields to search  (Default value = [])
+    ignore_case : bool
+      flag indicating if search is case sensitive   (Default value = True)
+    types : string
+      Type of bibliography entry to search  (Default value = 'all')
+
+    Returns
+    -------
+    list:
+      keys of entries where the expression is found
     """
     result = []
     for f in self.sortedList:
@@ -230,7 +336,7 @@ class BibList(dict):
         if findstr == '*':
           found = True
         else:
-          found = self.get_item(f).search(findstr, fields, caseSens)
+          found = self.get_item(f).search(findstr, fields, ignore_case)
         if found:
           result.append(f)
     return result
@@ -245,7 +351,7 @@ class BibList(dict):
 #     self.sort()
 
   def normalize(self):
-    '''Make bibtex key tha same that internal key'''
+    """Make bibtex key tha same that internal key"""
     for b in self.sortedList:
       self.get_item(b).normalize()
 
@@ -253,10 +359,19 @@ class BibList(dict):
       # import methods
       # 3
   def load(self, fname):
-    '''
-    Load a biblist from file "fname" using the standard cPickle module.
+    """Load a biblist from file "fname" using the standard cPickle module.
     It can be used uncompressed or compressed with gzip or bzip
-    '''
+
+    Parameters
+    ----------
+    fname : string or file-like
+      File where the bibliography is "dumped"
+
+    Returns
+    -------
+    Biblist object:
+      List of items found in file
+    """
     try:
       fi = helper.openfile(fname, 'rb')
       c = pickle.load(fi)
@@ -269,10 +384,16 @@ class BibList(dict):
       raise ValueError('Error updating data')
 
   def dump(self, fname, protocol=pickle.HIGHEST_PROTOCOL):
-    '''
-    Store the biblist in file "fname" using the standard cPickle module.
+    """Store the biblist in file "fname" using the standard cPickle module.
     It can be used uncompressed or compressed with gzip or bzip
-    '''
+
+    Parameters
+    ----------
+    fname : string or file-like
+
+    protocol :
+      Pickle protocol to use  (Default value = pickle.HIGHEST_PROTOCOL)
+    """
     # if not '.dmp' in fname: fname='%s.dmp' %(fname)
     try:
       fo = helper.openfile(fname, 'wb')
@@ -282,9 +403,17 @@ class BibList(dict):
       raise ValueError('Error loading data')
 
   def import_bibtex(self, fname=None, normalize=True, ReplaceAbbrevs=True):
-    """
-    Import a bibliography (set of items) from a file
-    If normalize the code (citekey) is overwritten with a standard key following our criteria
+    """Import a bibliography (set of items) from a file
+    If normalize the code (citekey) is overwritten with a standard key
+
+    Parameters
+    ----------
+    fname : string or file-like
+      Bibtex filename  (Default value = None)
+    normalize : bool
+      flag indicating if the key must be created (Default value = True)
+    ReplaceAbbrevs : bool
+      Replace all abbreviations in the items (Default value = True)
     """
     ncount = 0
     st, db = bibitem.bibparse.parsefile(fname)
@@ -294,38 +423,63 @@ class BibList(dict):
 
     self.keepAbbrevs = not ReplaceAbbrevs
     if db is not None:
-      for k, v in list(db.items()):
-        b1 = bibitem.BibItem(
-            bibitem.bibparse.replace_abbrevs(
-                self.abbrevDict,
-                dict(v)),
-            normalize=normalize)
-        key = b1.get_key()               # The key is generated
+      for k, v in list(db.items()):  # type(v) = dict
         if self.keepAbbrevs:
-          status = self.add_item(v, key)
-        else:
-          status = self.add_item(b1, key)
-        if status:
+          v = bibitem.bibparse.replace_abbrevs(self.abbrevDict, v)
+        key = self.add_item(v)
+        if key:
           ncount += 1
           if normalize:
             self.get_item(key).normalize()  # _code is put equal to key
     self.sort()
     return ncount
 
-  def import_ads(self, fname, normalize=True):
+  def import_database(self, fname, normalize=True):
+    """Import a bibliography from a sqlite database
+
+    Parameters
+    ----------
+    fname : Database filename
+
+    normalize : bool
+      flag indicating that key must be created (Default value = True)
     """
-    Import a bibliography (set of items) from a file
+    ncount = 0
+    db = bibitem.bibdb.parsefile(fname)
+
+    for k, v in db.items():
+      b1 = bibitem.BibItem(v, normalize=normalize)
+      # key = b1.get_key()               # The key generated
+      key = self.add_item(b1)
+      if key:
+        ncount += 1
+        if normalize:
+          self.get_item(key).normalize()  # _code is put equal to key
+
+    self.sort()
+    return ncount
+
+  def import_ads(self, fname, normalize=True):
+    """Import a bibliography (set of items) from a file
     If normalize the code (citekey) is overwritten with a standard key following our criteria
+
+    Parameters
+    ----------
+    fname : Database filename
+
+    normalize : bool
+      flag indicating that key must be created (Default value = True)
     """
     ncount = 0
     db = bibitem.adsparse.parsefile(fname)
     if db is not None:
       for k, v in list(db.items()):
-        status = self.add_item(v)
-        if status:
+        key = self.add_item(v)
+        if key:
           ncount += 1
           if normalize:
-            self.get_item(self.ListItems[-1]).normalize()
+            self.get_item(key).normalize()
+
     self.sort()
     return ncount
 
@@ -333,12 +487,28 @@ class BibList(dict):
     # export methods
 ##########################################################################
   def set_default_styles(self):
+    """Reset sytles to default values """
     for item in self.get_items():
       item.set_default_styles()
 
   def to_bibtex(self, indent=2, width=80, fields=None, encoding='latex'):
-    """
-    Export all entries to a bibtex file. All strings are resolved.
+    """Convert all entries to bibtex format. All strings are resolved.
+
+    Parameters
+    ----------
+    indent : int
+      Indent to use in bibtex file  (Default value = 2)
+    width : int
+      Width of paragraphs   (Default value = 80)
+    fields : list
+      List of fields to include in exported file (Default value = None)
+    encoding : string
+      Encoding to use for output file   (Default value = 'latex')
+
+    Returns
+    -------
+    string:
+      Contents of bibliography in bibtex form
     """
     if not self.issorted:
       self.sort()
@@ -367,8 +537,20 @@ class BibList(dict):
 
   def export_bibtex(self, fname=None, indent=2, width=80,
                     fields=None, encoding='latex'):
-    """
-    Export a bibliography (set of items) to a file in bibtex format:
+    """Export a bibliography (set of items) to a file in bibtex format:
+
+    Parameters
+    ----------
+    fname : string or file-like
+         (Default value = None)
+    indent : int
+      Indent to use in bibtex file  (Default value = 2)
+    width : int
+      Width of paragraphs   (Default value = 80)
+    fields : list
+      List of fields to include in exported file (Default value = None)
+    encoding : string
+      Encoding to use for output file   (Default value = 'latex')
     """
     fi = helper.openfile(fname, 'w')
     s = self.to_bibtex(indent, width, fields, encoding=encoding)
@@ -377,7 +559,71 @@ class BibList(dict):
     helper.closefile(fi)
 
   ##############################
+
+  def export_database(self, fname="biblio.db", fields=helper.allfields):
+    """Export a bibliography (set of items) to a file in bibtex format:
+
+    Parameters
+    ----------
+    fname : string or file-like
+         (Default value = "biblio.db")
+    indent : int
+      Indent to use in bibtex file  (Default value = 2)
+    width : int
+      Width of paragraphs   (Default value = 80)
+    fields : list
+      List of fields to include in exported file (Default value = helper.allfields)
+    """
+    fi = Path(fname)
+    con = bibdb.create_dbconnection(fi)
+    if con is None:
+      return None
+
+    tblnm, cols = bibdb.get_dbcolnames(con)
+    if tblnm == '':             # Empty database -> Create the table
+      tblnm = bibdb.DB_TBLNM
+      cols = fields
+      bibdb.create_dbbib(con, fields=cols, tablename=tblnm)
+    else:
+      try:
+        assert (tblnm == bibdb.DB_TBLNM and fields ==
+                helper.allfields), "Database table name and columns  must coincide exactly with default at this moment"
+      except AssertionError as e:
+        print(e)
+
+    # Agregamos los items
+    cur = con.cursor()
+    form = f"{','.join(len(cols)*'?')}"  # Formato
+    for it in self.get_items():
+      key = it.get_field('_code')
+      r = cur.execute(
+          f"SELECT EXISTS(SELECT 1 FROM {tblnm} WHERE _code='{key}' LIMIT 1);")
+      if r.fetchone()[0]:
+        print(f"Entry {key} already present. Not adding.")
+      else:
+        v = it.to_dbformat(fields=cols)
+        cur.execute(f"INSERT INTO {tblnm} VALUES({form});", tuple(v))
+
+    con.commit()
+    con.close()
+
+  ##############################
+
   def to_latex(self, style={}, label=r'\item'):
+    """Convert to latex form
+
+    Parameters
+    ----------
+    style : dict
+      Definition of style used for each field (Default value = {})
+    label : string
+      prefix to use before each entry (Default value = r'\\item')
+
+    Returns
+    -------
+    string:
+      Latex-formated list of items
+    """
     if not self.issorted:
       self.sort()
 
@@ -395,8 +641,20 @@ class BibList(dict):
 
   def export_latex(self, fname=None, style={},
                    label=r'\item', head=None, tail=None):
-    """
-    Export a bibliography (set of items) to a file in latex format:
+    """Export a bibliography (set of items) to a file in latex format:
+
+    Parameters
+    ----------
+    fname : string or file-like
+      Output filename (Default value = None)
+    style : dict
+      Definition of style used for each field (Default value = {})
+    label : string
+      prefix to use before each entry (Default value = r'\\item')
+    head : string
+      Text to include before list (Default value = None)
+    tail : string
+      Text to include after list (Default value = None)
     """
     if head is None:
       head = r'''\documentclass[12pt]{article}
@@ -411,7 +669,8 @@ class BibList(dict):
     #                                           label=label).encode('latex').decode('utf-8'),
     #                       tail)
     # fi = helper.openfile(fname, 'w'); fi.write(s); helper.closefile(fi)
-    # s = '%s\n%s\n%s\n' % (head, self.to_latex(style=style, label=label), tail)
+    # s = '%s\n%s\n%s\n' % (head, self.to_latex(style=style, label=label),
+    # tail)
     s = '{}\n{}\n{}\n'.format(
         head, self.to_latex(
             style=style, label=label), tail)
@@ -422,31 +681,59 @@ class BibList(dict):
 
   ##############################
   def to_html(self, style={}):
+    """Convert to html form
+
+    Parameters
+    ----------
+    style : dict
+      Definition of style used for each field (Default value = {})
+
+    Returns
+    -------
+    string:
+      Contents in html form
+    """
     if not self.issorted:
       self.sort()
 
     s = ''
-    for l in self.sortedList:
-      tipo = self.get_item(l).get_field('_type', 'article')
+    for li in self.sortedList:
+      tipo = self.get_item(li).get_field('_type', 'article')
 
       if self.keepAbbrevs:
         # copy the item to resolve_abbrevs
-        bib = bibitem.BibItem(self.get_item(l))
+        bib = bibitem.BibItem(self.get_item(li))
         bib.resolve_abbrevs(self.abbrevDict)
         ss = bib.to_html(style)
       else:
-        ss = self.get_item(l).to_html(style)
+        ss = self.get_item(li).to_html(style)
       s += '<li class="%s"> %s </li>\n' % (tipo, ss)
     return s
 
   def export_html(self, fname=None, style={}, head='', tail='',
                   separate_css='biblio.css', css_style=None, encoding='utf-8'):
-    """
-    Export a bibliography (set of items) to a file in html format: style is a dictionary
+    """Export a bibliography (set of items) to a file in html format: style is a dictionary
     (like in bibitem objects) where the values is a pair (open,close) to insert around the
     data.
-    head and tail are html code to insert before and after the list of publications
+    head and tail
     separate_css may have the
+
+    Parameters
+    ----------
+    fname : string or file-like
+      Output filename (Default value = None)
+    style : dict
+      Definition of style used for each field (Default value = {})
+    head : string
+      html code to insert before the list of publications  (Default value = '')
+    tail : string
+      html code to insert after the list of publications  (Default value = '')
+    separate_css : string
+      Name of a css style sheet file (Default value = 'biblio.css')
+    css_style : string
+      css style (Default value = None)
+    encoding : string
+      HTML encoding  (Default value = 'utf-8')
     """
     # default style
     def_css_style = """
@@ -527,27 +814,49 @@ div.abstract {display: none;padding: 0em 1% 0em 1%; border: 3px double rgb(130,1
 
   ##############################
   def to_xml(self, prefix='', indent=2):
+    """Convert to xml form
+
+    Parameters
+    ----------
+    prefix : string
+      Text to include before output  (Default value = '')
+    indent : int
+      Indent to use (Default value = 2)
+
+    Returns
+    -------
+    string:
+      Contents in xml format
+    """
     if not self.issorted:
       self.sort()
 
-    s = ''
-    for l in self.sortedList:
+    s = ""
+    for li in self.sortedList:
+      # copy the item to resolve_abbrevs
+      bib = bibitem.BibItem(self.get_item(li))
       if self.keepAbbrevs:
-        # copy the item to resolve_abbrevs
-        bib = bibitem.BibItem(self.get_item(l))
         bib.resolve_abbrevs(self.abbrevDict)
-        ss = bib.to_xml(p=prefix, indent=indent)
-      else:
-        ss = self.get_item(l).to_xml(p=prefix, indent=indent)
-
-      s += '%s' % (ss)
+      s += f"{bib.to_xml(p=prefix, indent=indent)}"
     return s
 
   def export_xml(self, fname=None, prefix='', head='', tail='', indent=2):
-    """
-    Export a bibliography (set of items) to a file in xml format:
-    A prefix may be added to account for a namespace. But if added both head and tail
+    """Export a bibliography (set of items) to a file in xml format:
+     But if added both head and tail
     should take it into account to make it a valid xml document
+
+    Parameters
+    ----------
+    fname : string or file-like
+      Output filename (Default value = None)
+    prefix : string
+      A prefix may be added to account for a namespace.  (Default value = '')
+    head : string
+      xml code to insert before the list of publications  (Default value = '')
+    tail : string
+      xml code to insert after the list of publications  (Default value = '')
+    indent : int
+         (Default value = 2)
     """
     if head == '':
       head = '''<?xml version="1.0" encoding="utf-8"?>
@@ -563,28 +872,52 @@ div.abstract {display: none;padding: 0em 1% 0em 1%; border: 3px double rgb(130,1
     helper.closefile(fi)
 
   def output(self, fout=None, formato=None, verbose=True):
-    """
-    Export all entries to a fout file with default options. All strings are resolved.
+    """Export all entries to a fout file with default options. All strings are resolved.
     following formats are defined:
-    short (default)
-    full
-    bibtex
-    latex
-    html
-    xml
+          short (default)
+          full
+          bibtex
+          latex
+          html
+          xml
+          database
+
+    Parameters
+    ----------
+    fout : string or file-like
+         (Default value = None)
+    formato : string
+      One of the possible formats (Default value = None)
+    verbose : bool
+      Print informational text (Default value = True)
+
     """
     def write_full(fout):
+      """Writer in full format
+
+      Parameters
+      ----------
+      fout : string or file-like
+      """
       fi = helper.openfile(fout, 'w')
       fi.write(str(self))
       helper.closefile(fi)
 
     def write_short(fout):
-      # fi = helper.openfile(fout, 'w'); fi.write(self.preview().encode(self.encoding))
+      """Output in Short format
+
+      Parameters
+      ----------
+      fout : string or file-like
+      """
+      # fi = helper.openfile(fout, 'w');
+      # fi.write(self.preview().encode(self.encoding))
       fi = helper.openfile(fout, 'w')
       fi.write(self.preview())
       helper.closefile(fi)
 
-    exp_meth = {'b': self.export_bibtex,
+    # Available export methods
+    exp_meth = {'b': self.export_bibtex, 'd': self.export_database,
                 'l': self.export_latex, 't': self.export_latex,
                 'h': self.export_html, 'x': self.export_xml,
                 's': write_short, 'f': write_full
