@@ -16,16 +16,24 @@ import re
 import string
 import codecs
 from . import latex
-# import latex
 latex.register()
 
-# import helper
-
 reg_pages = re.compile(r'\W+')
 
 
 def process_pages(pages):
-  """ Returns a 2-tuple (firstpage,lastpage) from a string"""
+  """Process a range of pages and return initial and final pages
+
+  Parameters
+  ----------
+  pages : string
+    a string of the form: xxx or mmm-nnn (where m and n are numbers)
+
+  Returns
+  -------
+  tuple of strings:
+    2-tuple (firstpage,lastpage)
+  """
   pp = reg_pages.split(pages)
   firstpage = pp[0]
   if len(pp) == 2:
@@ -36,16 +44,39 @@ def process_pages(pages):
 
 
 def bibtexauthor(data):
-  """ Returns a list of authors where each author is a list of the form:
-  [von, Last, First, Jr]
+  """Process a list of author in bibtex form and Returns a list of authors
+  where each author is a list of the form:
+
+                    [von, Last, First, Jr]
+
+  Parameters
+  ----------
+  data : string
+    Author list given in standard bibtex form
+
+
+  Returns
+  -------
+  list:
+    Each element is an author, described by a list
   """
   return list(map(helper.process_name, data.split(' and ')))
 
 
 def get_fields(strng, strict=False):
-  """
-  Returns a list with pairs (field, value) from strng
-  If strict is True, it will only allow known fields, defined in helper.bibtexfields
+  """Process a string from a bibtex entry and identify fields and values
+
+  Parameters
+  ----------
+  strng : string
+
+  strict : bool
+    If True, only fields recognized by program bibtex are included  (Default value = False)
+
+  Returns
+  -------
+  list:
+    Each element is a pair (field, value)
   """
 
   comma_rex = re.compile(r'\s*[,]')
@@ -100,21 +131,30 @@ def get_fields(strng, strict=False):
 
 # Creates a (hopefully) unique key code
 def create_entrycode(b={}):
-  """
-  Creates a 'hopefully unique' entry key from a bibtex item
+  """Creates a 'hopefully unique' entry key from a bibliography item
+
+  Parameters
+  ----------
+  b : dict
+    describes the bibliografy entry  (Default value = {})
+
+  Returns
+  -------
+  string:
+    An unique key code.
   """
   len_aut = 7  # Length of the author surname used
   try:
-    aut = helper.capitalizestring('%s%s' %
-                                  (b['author'][0][0], b['author'][0][1]))
+    aut = helper.capitalizestring(f"{b['author'][0][0]}{b['author'][0][1]}")
   except BaseException:
-    print((b['author']))
-    print((b['_code']))
-  aut = helper.oversimplify(aut)
+    print("Error in bibparse.create_entrycode: ",
+          (b['author']), (b['_code']), sep="\n")
+
+  aut = helper.oversimplify(aut).strip()
   if len(aut) > len_aut:
     bibid = aut[:len_aut]
   else:
-    bibid = aut.strip()
+    bibid = aut
 
   bibid += b.get('year', '')
   bibid += b.get('journal_abbrev', '')
@@ -141,7 +181,21 @@ def create_entrycode(b={}):
 
 
 def replace_abbrevs(strs, bitem):
-  """ Resolve all abbreviations found in the value fields of one entry"""
+  """Resolve all abbreviations found in the value fields of one entry
+
+  Parameters
+  ----------
+  strs : string
+    STRING defined in bibtex file
+
+  bitem : dict-like
+    bibliography item
+
+  Returns
+  -------
+  dict-like:
+    modified bibliography item
+  """
   b = bitem
   for f, v in list(b.items()):
     if helper.is_string_like(v):
@@ -150,6 +204,20 @@ def replace_abbrevs(strs, bitem):
 
 
 def parsefile(fname=None):
+  """
+  Read and parses a bibtex file (*.bib)
+
+  Parameters
+  ----------
+  fname : string or file-like
+    Filename or file-handler   (Default value = None)
+
+  Returns
+  -------
+  dict:
+    Each element is a dict whose value describes a bibliography entry.
+    Its key is generated automatically from the data
+  """
   fi = helper.openfile(fname)
   s = fi.read()
   db = parsedata(s)
@@ -157,8 +225,18 @@ def parsefile(fname=None):
 
 
 def parsedata(data):
-  """
-  Parses a string with a bibtex database
+  """Parses a string with a bibtex database
+
+  Parameters
+  ----------
+  data : string
+    Contents of a bibtex file
+
+  Returns
+  -------
+  tuple: (strings, entries)
+    - strings is a dict with all defined strings
+    - entries is a dict with all the bibtex entries
   """
   # Regular expressions to use
   # A '@' followed by any word and an opening
@@ -203,8 +281,16 @@ def parsedata(data):
 
 
 def parseentry(source):
-  """
-  Reads an item in bibtex form from a string
+  """Reads an item in bibtex form from a string
+
+  Parameters
+  ----------
+  source : string
+
+  Returns
+  -------
+  tuple: (None, entry) or (string, None)
+  depending if the source has a bibtex STRING definition or an entry
   """
   try:
     source + ' '
@@ -239,9 +325,9 @@ def parseentry(source):
     entry['_code'] = p.group()[:-1]
     ff = get_fields(s[2][p.end():])
     for n, d in ff:
-      if n == 'author' or n == 'editor':
+      if n in helper.namefields:
         entry[n] = bibtexauthor(d)
-      elif n == 'title' or n == 'abstract':
+      elif n in ['title', 'abstract']:
         t = helper.capitalizestring(d)
         # JF: Algo no está bien. Porque no estoy convertiendo latex a strings
         # entry[n] = codecs.decode(t, 'latex+utf8', 'ignore')
@@ -262,6 +348,7 @@ def parseentry(source):
 
 
 def test():
+  """Test """
   if sys.argv[1:]:
     filepath = sys.argv[1]
   else:
