@@ -4,24 +4,28 @@ import sys
 import collections
 from pathlib import Path
 #        ################################ Variables  #####################
-# List of all possible fields.
-allfields = ('_type', 'address', 'author', 'booktitle', 'chapter', 'edition', '_code',
-             'editor', 'howpublished', 'institution', 'journal', 'month', 'number', 'organization',
-             'pages', 'publisher', 'school', 'series', 'title', 'volume', 'year', 'note', 'code',
-             'url', 'crossref', 'annote', 'abstract', 'doi', 'journal_abbrev', 'date-added', 'date-modified', 'file')
+bibtexfields = ['abstract', 'address', 'affiliation', 'annote', 'author', 'booktitle', 'chapter',
+                'crossref', 'day', 'doi', 'edition', 'editor', 'file', 'howpublished',
+                'institution', 'isbn', 'issn', 'journal', 'keywords', 'month', 'note',
+                'number', 'organization', 'pages', 'publisher', 'school', 'series', 'title',
+                'url', 'volume', 'year']
 
-bibtexfields = ('author', 'title', 'journal', 'year', 'volume', 'number', 'pages', 'month',
-                'booktitle', 'chapter', 'address', 'edition', 'abstract', 'doi', 'url', 'editor',
-                'howpublished', 'school', 'institution', 'organization', 'publisher', 'series',
-                'note', 'crossref', 'annote', 'file')
+# Fields that are output literally in bibtex form
+textualfields = ['_code', 'abstract', 'address', 'annote', 'booktitle', 'chapter', 'crossref', 'doi', 'edition',
+                 'file', 'howpublished', 'institution', 'isbn', 'issn', 'journal', 'keywords', 'month',
+                 'note', 'number', 'organization', 'publisher', 'school', 'series', 'title', 'url', 'volume', 'year']
+
+# Some fields that MAY appear + "_code" and "_type"
+otherfields = ['_code', '_type', 'code', 'date-added', 'date-modified',
+               'daynote', 'firstpage', 'journal_abbrev', 'lastpage']
+
+# List of all possible fields.
+allfields = sorted(bibtexfields + otherfields)
 
 # Fields that MUST be present
 minimalfields = ('_type', 'author')
 
-# Fields that are output literally in bibtex form
-textualfields = ['title', 'journal', 'year', 'volume', 'number', 'month', 'booktitle', 'chapter',
-                 'address', 'edition', 'howpublished', 'school', 'institution', 'organization', 'publisher', 'series',
-                 'note', 'crossref', 'issn', 'isbn', 'keywords', 'annote', '_code', 'doi', 'url', 'abstract', 'file']
+namefields = ['author', 'editor']  # Fields that must be treated as names
 
 # Fields that should not be wrapped (must go complete in the same line)
 nowrapfields = ['url', 'doi', 'isbn', 'issn', 'crossref']
@@ -208,6 +212,16 @@ journal_data = [
 ]
 
 
+def make_unique(lista):
+  """Keep only unique elements of list
+  """
+  f = []
+  for it in lista:
+    if it not in f:
+      f.append(it)
+  return f
+
+
 def is_string_like(obj):
   'Return True if *obj* looks like a string (from matplotlib)'
   if isinstance(obj, str):
@@ -245,14 +259,6 @@ def to_filehandle(fname, flag='r', return_opened=False, encoding=None):
   """
   if is_string_like(fname):
     fh = Path(fname).open(mode=flag)
-    # if fname.endswith('.gz'):
-    #   import gzip
-    #   fh = gzip.open(fname, flag)
-    # elif fname.endswith('.bz2'):
-    #   import bz2
-    #   fh = bz2.BZ2File(fname, flag)
-    # else:
-    #   fh = open(fname, mode=flag)
     opened = True
   elif isinstance(fname, Path):
     fh = fname.open(mode=flag)
@@ -260,36 +266,35 @@ def to_filehandle(fname, flag='r', return_opened=False, encoding=None):
     fh = fname
     opened = False
   else:
-    raise ValueError('fname must be a string or file handle')
+    raise ValueError('fname must be a pathlib Path, string or file handle')
   if return_opened:
     return fh, opened
   return fh
 
 
 def tsplit(s, sep):
-  def tsplit(s, sep):
-    """Splits a string like split but allows for several char delimiters
-    Example:
-    >>> tsplit("hello,my|name+is-bob", (",", "|", "+", "-"))
-    ['hello', 'my', 'name', 'is', 'bob']
-    >>> tsplit("hello,my|name+is-bob", ",|+-")
-    ['hello', 'my', 'name', 'is', 'bob']
-    >>> tsplit("hello,my|name+is-bob", list(",|+-"))
-    ['hello', 'my', 'name', 'is', 'bob']
-    >>> tsplit("hello,my|name+is-bob", "+")
-    ['hello,my|name', 'is-bob']
+  """Splits a string like split but allows for several char delimiters
+  Example:
+  >>> tsplit("hello,my|name+is-bob", (",", "|", "+", "-"))
+  ['hello', 'my', 'name', 'is', 'bob']
+  >>> tsplit("hello,my|name+is-bob", ",|+-")
+  ['hello', 'my', 'name', 'is', 'bob']
+  >>> tsplit("hello,my|name+is-bob", list(",|+-"))
+  ['hello', 'my', 'name', 'is', 'bob']
+  >>> tsplit("hello,my|name+is-bob", "+")
+  ['hello,my|name', 'is-bob']
 
-    Arguments:
-    - `s`: string to separate
-    - `sep`: separators
-    """
-    stack = [s]
-    for char in sep:
-      pieces = []
-      for substr in stack:
-        pieces.extend(substr.split(char))
-      stack = pieces
-    return stack
+  Arguments:
+  - `s`: string to separate
+  - `sep`: separators
+  """
+  stack = [s]
+  for char in sep:
+    pieces = []
+    for substr in stack:
+      pieces.extend(substr.split(char))
+    stack = pieces
+  return stack
 
 
 def openfile(fname=None, intent='r', encoding=None):
@@ -321,10 +326,45 @@ def closefile(fi):
 
 
 reg_defstrng = re.compile(
-    '[{]*DEFINITIONOFSTRING[(](\w+)[)][{]*(\s*[#]*\s*["]*\s*\w*\s*["]*\s*)[}]*', re.I)
+    '[{]*DEFINITIONOFSTRING[(](\\w+)[)][{]*(\\s*[#]*\\s*["]*\\s*\\w*\\s*["]*\\s*)[}]*', re.I)
 # reg_defstrng= re.compile('[{]*DEFINITIONOFSTRING[(](\w+)[)][}]*',re.I)
 
 
+def verify_entry(b):
+  """Verify that the entry is valid (minimal fields are present)
+
+  Parameters
+  ----------
+  b : dict
+    entry values
+
+  Returns
+  -------
+  bool:
+    True if is valid
+  """
+  for f in minimalfields:
+    if f not in b:
+      return False
+  return True
+
+
+def add_journal_abbrev(b):
+  """Try to add journal abbreviation
+
+  Parameters
+  ----------
+  b : dict
+    entry values
+  """
+  if 'journal' in b:
+    if 'journal_abbrev' not in b:
+      # Create one abbrev
+      journal, abbrev = identify_some_journals(b)
+      b['journal_abbrev'] = abbrev
+      b['journal'] = journal
+
+
 def replace_abbrevs(strs, sourcestrng):
   if 'DEFINITIONOFSTRING' in sourcestrng or 'definitionofstring' in sourcestrng:
     v = sourcestrng
@@ -530,14 +570,23 @@ def removebraces(str):
   return rembraces_rex.sub('', str)
 
 
-# data = title string
-# @return the capitalized string (first letter is capitalized), rest are capitalized
-# only if capitalized inside braces
 capitalize_rex = re.compile(r'({\w*})')
 cap_rex = re.compile('{([a-zA-Z]*)}')
 
 
 def capitalizestring(data):
+  """Capitalizes a string keeping verbatim characters between braces
+
+  Parameters
+  ----------
+  data = title string
+
+  Returns
+  -------
+  string:
+    the capitalized string (first letter is capitalized), rest are capitalized
+    only if capitalized inside braces
+  """
   ss_list = capitalize_rex.split(data)
   ss = ''
   count = 0
@@ -647,7 +696,8 @@ def replace_tags(strng, what='All'):
   if ww == 'all' or ww == 'accents':
     # latex-specific character replacements
     for i, o in accent_tags:
-      strng = string.replace(strng, i, o)
+      # strng = string.replace(strng, i, o)
+      strng = strng.replace(i, o)
 
   if ww == 'all' or ww == 'other':
     # Other LaTeX tags, handled by regexps
